vaccel

package
v0.0.0-...-3b8d5ff Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 15, 2025 License: Apache-2.0 Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func ExecWithResource

func ExecWithResource(sess *Session, res *Resource, funcname string,
	read *ArgList, write *ArgList) int

func ImageClassification

func ImageClassification(sess *Session, image []byte) (string, int)

func ImageClassificationFromFile

func ImageClassificationFromFile(sess *Session, imagePath string) (string, int)

func NoOp

func NoOp(sess *Session) int

func ResourceInit

func ResourceInit(res *Resource, path string, resType ResourceType) int

func ResourceRegister

func ResourceRegister(res *Resource, sess *Session) int

func ResourceRelease

func ResourceRelease(res *Resource) int

func ResourceUnregister

func ResourceUnregister(res *Resource, sess *Session) int

func SessionInit

func SessionInit(sess *Session, flags uint32) int

func SessionRelease

func SessionRelease(sess *Session) int

Types

type Arg

type Arg struct {
	// contains filtered or unexported fields
}

func (*Arg) ExtractSerialArg

func (args *Arg) ExtractSerialArg(idx int) unsafe.Pointer

type ArgList

type ArgList struct {
	// contains filtered or unexported fields
}

func ArgsInit

func ArgsInit(size uint32) *ArgList

func (*ArgList) AddNonSerialArg

func (arglist *ArgList) AddNonSerialArg(nonSerialBuf unsafe.Pointer,
	argtype uint32, serialize Serializer) int

func (*ArgList) AddSerialArg

func (arglist *ArgList) AddSerialArg(buf unsafe.Pointer, size uintptr) int

func (*ArgList) Delete

func (arglist *ArgList) Delete() int

func (*ArgList) ExpectNonSerialArg

func (arglist *ArgList) ExpectNonSerialArg(expectedSize uintptr) int

func (*ArgList) ExpectSerialArg

func (arglist *ArgList) ExpectSerialArg(buf unsafe.Pointer, size uintptr) int

func (*ArgList) ExtractNonSerialArg

func (arglist *ArgList) ExtractNonSerialArg(idx int, deserialize Deserializer) unsafe.Pointer

func (*ArgList) ExtractSerialArg

func (arglist *ArgList) ExtractSerialArg(idx int) unsafe.Pointer

func (*ArgList) GetArgs

func (arglist *ArgList) GetArgs() *Arg

type Deserializer

type Deserializer func(buf unsafe.Pointer) unsafe.Pointer

Type of function to deserialize a structure Returns pointer to the constructed structure

type Resource

type Resource struct {
	// contains filtered or unexported fields
}

type ResourceType

type ResourceType int
const (
	ResourceLib ResourceType = iota
	ResourceData
	ResourceModel
)

func (ResourceType) ToCEnum

type Serializer

type Serializer func(buf unsafe.Pointer) (unsafe.Pointer, uint32)

Type of function to serialize a structure Returns pointer to serialized data and the size in bytes

type Session

type Session struct {
	// contains filtered or unexported fields
}

Jump to