Documentation
¶
Index ¶
- func ExecWithResource(sess *Session, res *Resource, funcname string, read *ArgList, write *ArgList) int
- func ImageClassification(sess *Session, image []byte) (string, int)
- func ImageClassificationFromFile(sess *Session, imagePath string) (string, int)
- func NoOp(sess *Session) int
- func ResourceInit(res *Resource, path string, resType ResourceType) int
- func ResourceRegister(res *Resource, sess *Session) int
- func ResourceRelease(res *Resource) int
- func ResourceUnregister(res *Resource, sess *Session) int
- func SessionInit(sess *Session, flags uint32) int
- func SessionRelease(sess *Session) int
- type Arg
- type ArgList
- func (arglist *ArgList) AddNonSerialArg(nonSerialBuf unsafe.Pointer, argtype uint32, serialize Serializer) int
- func (arglist *ArgList) AddSerialArg(buf unsafe.Pointer, size uintptr) int
- func (arglist *ArgList) Delete() int
- func (arglist *ArgList) ExpectNonSerialArg(expectedSize uintptr) int
- func (arglist *ArgList) ExpectSerialArg(buf unsafe.Pointer, size uintptr) int
- func (arglist *ArgList) ExtractNonSerialArg(idx int, deserialize Deserializer) unsafe.Pointer
- func (arglist *ArgList) ExtractSerialArg(idx int) unsafe.Pointer
- func (arglist *ArgList) GetArgs() *Arg
- type Deserializer
- type Resource
- type ResourceType
- type Serializer
- type Session
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ExecWithResource ¶
func ResourceInit ¶
func ResourceInit(res *Resource, path string, resType ResourceType) int
func ResourceRegister ¶
func ResourceRelease ¶
func ResourceUnregister ¶
func SessionInit ¶
func SessionRelease ¶
Types ¶
type ArgList ¶
type ArgList struct {
// contains filtered or unexported fields
}
func (*ArgList) AddNonSerialArg ¶
func (*ArgList) AddSerialArg ¶
func (*ArgList) ExpectNonSerialArg ¶
func (*ArgList) ExpectSerialArg ¶
func (*ArgList) ExtractNonSerialArg ¶
func (arglist *ArgList) ExtractNonSerialArg(idx int, deserialize Deserializer) unsafe.Pointer
type Deserializer ¶
Type of function to deserialize a structure Returns pointer to the constructed structure
type ResourceType ¶
type ResourceType int
const ( ResourceLib ResourceType = iota ResourceData ResourceModel )
func (ResourceType) ToCEnum ¶
func (t ResourceType) ToCEnum() C.vaccel_resource_type_t
type Serializer ¶
Type of function to serialize a structure Returns pointer to serialized data and the size in bytes
Click to show internal directories.
Click to hide internal directories.